You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by al...@apache.org on 2017/05/12 00:11:59 UTC

[05/19] beam git commit: Add internal usage only comments to util/

Add internal usage only comments to util/


Project: http://git-wip-us.apache.org/repos/asf/beam/repo
Commit: http://git-wip-us.apache.org/repos/asf/beam/commit/9730f56e
Tree: http://git-wip-us.apache.org/repos/asf/beam/tree/9730f56e
Diff: http://git-wip-us.apache.org/repos/asf/beam/diff/9730f56e

Branch: refs/heads/release-2.0.0
Commit: 9730f56eaf62c8164a517d5fe0cc03650c39a732
Parents: 65aa0ff
Author: Ahmet Altay <al...@google.com>
Authored: Thu May 11 11:34:59 2017 -0700
Committer: Ahmet Altay <al...@google.com>
Committed: Thu May 11 16:20:36 2017 -0700

----------------------------------------------------------------------
 sdks/python/apache_beam/utils/__init__.py    | 5 ++++-
 sdks/python/apache_beam/utils/annotations.py | 4 +++-
 sdks/python/apache_beam/utils/counters.py    | 5 ++++-
 sdks/python/apache_beam/utils/processes.py   | 6 +++++-
 sdks/python/apache_beam/utils/profiler.py    | 5 ++++-
 sdks/python/apache_beam/utils/proto_utils.py | 2 ++
 sdks/python/apache_beam/utils/retry.py       | 2 ++
 sdks/python/apache_beam/utils/timestamp.py   | 5 ++++-
 sdks/python/apache_beam/utils/urns.py        | 2 ++
 9 files changed, 30 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/__init__.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/annotations.py b/sdks/python/apache_beam/utils/annotations.py
index 92318b1..017dd6b 100644
--- a/sdks/python/apache_beam/utils/annotations.py
+++ b/sdks/python/apache_beam/utils/annotations.py
@@ -15,7 +15,9 @@
 # limitations under the License.
 #
 
-""" Deprecated and experimental annotations.
+"""Deprecated and experimental annotations.
+
+For internal use only; no backwards-compatibility guarantees.
 
 Annotations come in two flavors: deprecated and experimental
 

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/counters.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/counters.py b/sdks/python/apache_beam/utils/counters.py
index e41d732..b379461 100644
--- a/sdks/python/apache_beam/utils/counters.py
+++ b/sdks/python/apache_beam/utils/counters.py
@@ -18,7 +18,10 @@
 # cython: profile=False
 # cython: overflowcheck=True
 
-"""Counters collect the progress of the Worker for reporting to the service."""
+"""Counters collect the progress of the Worker for reporting to the service.
+
+For internal use only; no backwards-compatibility guarantees.
+"""
 
 import threading
 from apache_beam.transforms import cy_combiners

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/processes.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/processes.py b/sdks/python/apache_beam/utils/processes.py
index e089090..e5fd9c8 100644
--- a/sdks/python/apache_beam/utils/processes.py
+++ b/sdks/python/apache_beam/utils/processes.py
@@ -14,7 +14,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-"""Cross-platform utilities for creating subprocesses."""
+
+"""Cross-platform utilities for creating subprocesses.
+
+For internal use only; no backwards-compatibility guarantees.
+"""
 
 import platform
 import subprocess

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/profiler.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/profiler.py b/sdks/python/apache_beam/utils/profiler.py
index 852b659..a2c3f6a 100644
--- a/sdks/python/apache_beam/utils/profiler.py
+++ b/sdks/python/apache_beam/utils/profiler.py
@@ -15,7 +15,10 @@
 # limitations under the License.
 #
 
-"""A profiler context manager based on cProfile.Profile objects."""
+"""A profiler context manager based on cProfile.Profile objects.
+
+For internal use only; no backwards-compatibility guarantees.
+"""
 
 import cProfile
 import logging

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/proto_utils.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/proto_utils.py b/sdks/python/apache_beam/utils/proto_utils.py
index d929a92..090a821 100644
--- a/sdks/python/apache_beam/utils/proto_utils.py
+++ b/sdks/python/apache_beam/utils/proto_utils.py
@@ -15,6 +15,8 @@
 # limitations under the License.
 #
 
+"""For internal use only; no backwards-compatibility guarantees."""
+
 from google.protobuf import any_pb2
 from google.protobuf import struct_pb2
 

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/retry.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/retry.py b/sdks/python/apache_beam/utils/retry.py
index 2c32f0f..1a8b907 100644
--- a/sdks/python/apache_beam/utils/retry.py
+++ b/sdks/python/apache_beam/utils/retry.py
@@ -17,6 +17,8 @@
 
 """Retry decorators for calls raising exceptions.
 
+For internal use only; no backwards-compatibility guarantees.
+
 This module is used mostly to decorate all integration points where the code
 makes calls to remote services. Searching through the code base for @retry
 should find all such places. For this reason even places where retry is not

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/timestamp.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/timestamp.py b/sdks/python/apache_beam/utils/timestamp.py
index 8b2ccda..5d1b48c 100644
--- a/sdks/python/apache_beam/utils/timestamp.py
+++ b/sdks/python/apache_beam/utils/timestamp.py
@@ -15,7 +15,10 @@
 # limitations under the License.
 #
 
-"""Timestamp utilities."""
+"""Timestamp utilities.
+
+For internal use only; no backwards-compatibility guarantees.
+"""
 
 from __future__ import absolute_import
 

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/urns.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/utils/urns.py b/sdks/python/apache_beam/utils/urns.py
index 46bd8f5..379b5ff 100644
--- a/sdks/python/apache_beam/utils/urns.py
+++ b/sdks/python/apache_beam/utils/urns.py
@@ -15,6 +15,8 @@
 # limitations under the License.
 #
 
+"""For internal use only; no backwards-compatibility guarantees."""
+
 import abc
 import inspect
diff --git a/sdks/python/apache_beam/utils/__init__.py b/sdks/python/apache_beam/utils/__init__.py
index 74cf45d..635c80f 100644
--- a/sdks/python/apache_beam/utils/__init__.py
+++ b/sdks/python/apache_beam/utils/__init__.py
@@ -15,4 +15,7 @@
 # limitations under the License.
 #
 
-"""A package containing utilities."""
+"""A package containing internal utilities.
+
+For internal use only; no backwards-compatibility guarantees.
+"""

http://git-wip-us.apache.org/repos/asf/beam/blob/9730f56e/sdks/python/apache_beam/utils/annotations.py
----------------------------------------------------------------------